From a72d792a39a41bb8f65976b1f542c523b65997bf Mon Sep 17 00:00:00 2001
From: Wang Xingchao <xingchao.wang@linux.intel.com>
Date: Fri, 3 May 2013 15:28:13 +0800
Subject: [RFC PATCH 4/4] Alsa: hda - Add power well API in codec driver

Add get/put power well in codec's suspend/resume callback.

TODO:
As power well also has impact on HDA controller registers, azx_probe()
also need request power well.

Signed-off-by: Wang Xingchao <xingchao.wang@linux.intel.com>
---
 sound/pci/hda/hda_codec.c |   11 +++++++++--
 1 file changed, 9 insertions(+), 2 deletions(-)

diff --git a/sound/pci/hda/hda_codec.c b/sound/pci/hda/hda_codec.c
index 04a8ba4..7738440 100644
--- a/sound/pci/hda/hda_codec.c
+++ b/sound/pci/hda/hda_codec.c
@@ -39,6 +39,7 @@
 
 #define CREATE_TRACE_POINTS
 #include "hda_trace.h"
+#include "hdmi_i915.h"
 
 /*
  * vendor / preset table
@@ -5510,12 +5511,15 @@ EXPORT_SYMBOL_HDA(snd_hda_add_imux_item);
 int snd_hda_suspend(struct hda_bus *bus)
 {
 	struct hda_codec *codec;
+	struct hdmi_i915_private *i915_data;
 
 	list_for_each_entry(codec, &bus->codec_list, list) {
 		cancel_delayed_work_sync(&codec->jackpoll_work);
 		if (hda_codec_is_power_on(codec))
 			hda_call_codec_suspend(codec, false);
-		//TODO: Get codec private i915 data and release power well
+		i915_data = dev_get_drvdata(&codec->dev);
+		if (i915_data && i915_data->put_power_well)
+			i915_data->put_power_well();
 	}
 	return 0;
 }
@@ -5530,9 +5534,12 @@ EXPORT_SYMBOL_HDA(snd_hda_suspend);
 int snd_hda_resume(struct hda_bus *bus)
 {
 	struct hda_codec *codec;
+	struct hdmi_i915_private *i915_data;
 
 	list_for_each_entry(codec, &bus->codec_list, list) {
-		//TODO: Get codec private i915 data and request power well
+		i915_data = dev_get_drvdata(&codec->dev);
+		if (i915_data && i915_data->get_power_well)
+			i915_data->get_power_well();
 		hda_call_codec_resume(codec);
 	}
 	return 0;
-- 
1.7.9.5

